==> gs2-cdk-1.0.86.tar.gz: gs2-cdk-1.0.86/src/gs2_cdk/ranking/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .CategoryModel import CategoryModel
from .options.CategoryModelOptions import CategoryModelOptions
from .enum.CategoryModelOrderDirection import CategoryModelOrderDirection
from .enum.CategoryModelScope import CategoryModelScope
from .options.CategoryModelScopeIsGlobalOptions import CategoryModelScopeIsGlobalOptions
from .options.CategoryModelScopeIsScopedOptions import CategoryModelScopeIsScopedOptions
from .Scope import Scope
from .options.ScopeOptions import ScopeOptions
from .GlobalRankingSetting import GlobalRankingSetting
from .options.GlobalRankingSettingOptions import GlobalRankingSettingOptions
from .FixedTiming import FixedTiming
from .options.FixedTimingOptions import FixedTimingOptions
from .CalculatedAt import CalculatedAt
from .options.CalculatedAtOptions import CalculatedAtOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.94.tar.gz: gs2-cdk-1.0.94/src/gs2_cdk/ranking/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .CategoryModel import CategoryModel
from .options.CategoryModelOptions import CategoryModelOptions
from .enums.CategoryModelOrderDirection import CategoryModelOrderDirection
from .enums.CategoryModelScope import CategoryModelScope
from .options.CategoryModelScopeIsGlobalOptions import CategoryModelScopeIsGlobalOptions
from .options.CategoryModelScopeIsScopedOptions import CategoryModelScopeIsScopedOptions
from .Scope import Scope
from .options.ScopeOptions import ScopeOptions
from .GlobalRankingSetting import GlobalRankingSetting
from .options.GlobalRankingSettingOptions import GlobalRankingSettingOptions
from .FixedTiming import FixedTiming
from .options.FixedTimingOptions import FixedTimingOptions
from .CalculatedAt import CalculatedAt
from .options.CalculatedAtOptions import CalculatedAtOptions
from .CurrentMasterData import CurrentMasterData
